# Storage Account Drop Off
resource "azurerm_storage_account" "storage_drop" {
  name                      = local.cloudockit_storage.drop
  resource_group_name       = azurerm_resource_group.rgproject.name
  location                  = azurerm_resource_group.rgproject.location
  account_tier              = "Standard"
  account_replication_type  = "LRS"
  account_kind              = "StorageV2"
  enable_https_traffic_only = true
  min_tls_version           = "TLS1_2"
  allow_blob_public_access  = false
  tags                      = local.common_tags
}

# Storage Account Docker API
resource "azurerm_storage_account" "storage_cloudockit" {
  name                      = local.cloudockit_storage.licence
  resource_group_name       = azurerm_resource_group.rgproject.name
  location                  = azurerm_resource_group.rgproject.location
  account_tier              = "Standard"
  account_replication_type  = "LRS"
  account_kind              = "StorageV2"
  enable_https_traffic_only = true
  min_tls_version           = "TLS1_2"
  allow_blob_public_access  = false
  tags                      = local.common_tags
}
resource "azurerm_storage_container" "cloudockitinternal" {
  name                  = "cloudockitinternal"
  storage_account_name  = azurerm_storage_account.storage_cloudockit.name
  container_access_type = "private"
}
resource "azurerm_storage_blob" "cloudockitinternal_license" {
  name                   = "license.json"
  storage_account_name   = azurerm_storage_account.storage_cloudockit.name
  storage_container_name = azurerm_storage_container.cloudockitinternal.name
  type                   = "Block"
  source                 = "license.json"
}

# RBAC Access for SPN
resource "azurerm_role_assignment" "rbac_storage_data" {
  scope                = azurerm_storage_account.storage_drop.id
  role_definition_name = "Storage Blob Data Contributor"
  principal_id         = azuread_service_principal.aad_cloudockit_spn.object_id
}

resource "azurerm_role_assignment" "rbac_storage_key" {
  scope                = azurerm_storage_account.storage_drop.id
  role_definition_name = "Storage Account Key Operator Service Role"
  principal_id         = azuread_service_principal.aad_cloudockit_spn.object_id
}
