# Guide : https://generate.cloudockit.com/ContainerGuide/ContainerGuide_Azure.pdf

resource "azurerm_app_service_plan" "serviceplan" {
  name                = "PLAN-${local.project}-${local.environment}"
  location            = azurerm_resource_group.rgproject.location
  resource_group_name = azurerm_resource_group.rgproject.name
  kind                = "Linux"
  reserved            = true
  sku {
    tier = local.cloudockit_plan.tier
    size = local.cloudockit_plan.size
  }
  tags = local.common_tags
}

resource "azurerm_app_service" "docker_api" {
  name                    = "APP-${local.project}-${local.environment}"
  location                = azurerm_resource_group.rgproject.location
  resource_group_name     = azurerm_resource_group.rgproject.name
  app_service_plan_id     = azurerm_app_service_plan.serviceplan.id
  https_only              = true
  client_affinity_enabled = false

  site_config {
    dotnet_framework_version  = "v4.0"
    scm_type                  = "None"
    always_on                 = true
    ftps_state                = "AllAllowed"
    remote_debugging_enabled  = false
    min_tls_version           = "1.2"
    managed_pipeline_mode     = "Integrated"
    use_32_bit_worker_process = false
    http2_enabled             = true
    linux_fx_version          = "DOCKER|${local.cloudockit_container.registry}/cdk-web-linux:latest"
  }


  app_settings = {
    "DOCKER_REGISTRY_SERVER_PASSWORD"     = local.cloudockit_container.password
    "DOCKER_REGISTRY_SERVER_URL"          = "https://${local.cloudockit_container.registry}"
    "DOCKER_REGISTRY_SERVER_USERNAME"     = local.cloudockit_container.user
    "WEBSITES_ENABLE_APP_SERVICE_STORAGE" = false

    "WEBSITE_MEMORY_LIMIT_MB"                 = local.cloudockit_memory
    "DockerStorageCloudProvider"              = "Azure"
    "DockerStorageAzureCnxString"             = azurerm_storage_account.storage_cloudockit.primary_connection_string
    "AppInsightKey"                           = azurerm_application_insights.applicationinsights.instrumentation_key
    "ApplicationInsights__InstrumentationKey" = azurerm_application_insights.applicationinsights.instrumentation_key

  }

  tags = local.common_tags
}
